<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
North Sámi
</name>

<description>  
North Sámi dictionary for hunspell
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
hunspell-se
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
hunspell-se
</uninstall_package_names>

</app>
